#!/bin/python3
# coding: utf-8
"""
A Sphinx extension that enables inline bold + italic.

https://github.com/kallimachos/bolditalic

Copyright 2016 Brian Moss
"""

import os
from docutils import nodes
from shutil import copy


def css(app, env):
    """
    Add bolditalic CSS.

    :param app: Sphinx application context.
    :param env: Sphinx environment context.
    """
    srcdir = os.path.abspath(os.path.dirname(__file__))
    app.info("srcdir: " + srcdir)
    cssfile = 'bolditalic.css'
    app.info("cssfile: " + cssfile)
    csspath = os.path.join(srcdir, cssfile)
    app.info("csspath: " + csspath)
    buildpath = os.path.join(app.outdir, '_static')
    app.info("buildpath: " + buildpath)
    try:
        os.makedirs(buildpath)
        app.info("Created: " + buildpath)
    except OSError:
        app.info("Already exists: " + buildpath)
        if not os.path.isdir(buildpath):
            raise
    copy(csspath, buildpath)
    app.info("copy " + csspath + " to " + buildpath)
    app.add_stylesheet(cssfile)
    app.info(cssfile + " stylesheet added")
    return


def bolditalic(name, rawtext, text, lineno, inliner, options={}, content=[]):
    """
    Add bolditalic role.

    Returns 2 part tuple containing list of nodes to insert into the
    document and a list of system messages.  Both are allowed to be
    empty.

    :param name: The role name used in the document.
    :param rawtext: The entire markup snippet, with role.
    :param text: The text marked with the role.
    :param lineno: The line number where rawtext appears in the input.
    :param inliner: The inliner instance that called this function.
    :param options: Directive options for customization.
    :param content: The directive content for customization.
    """
    node = nodes.inline(rawtext, text)
    node.set_class('bolditalic')
    return [node], []


def setup(app):
    """
    Setup for Sphinx extension.

    :param app: Sphinx application context.
    """
    try:
        app.info('adding bolditalic role...', nonl=True)
        app.add_role('bolditalic', bolditalic)
        app.connect('env-updated', css)
        app.info(' done')
    except:
        app.warn('Failed to initialize bolditalic styling.')
    return {'version': '0.1.0'}


if __name__ == '__main__':
    pass
